<?php

namespace Drupal\abuseipdb\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Form that tracks a list of pathnames to check.
 */
class Paths extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'abuseipdb_paths_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {

    // Form Constructor.
    $form = parent::buildForm($form, $form_state);
    // Default Settings.
    $config = $this->config('abuseipdb.settings');

    $form['paths'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Paths'),
      '#default_value' => $config->get('abuseipdb.paths'),
      '#description' => $this->t("Specify pages where the visitor's ip needs to be reported. Enter one path per line. Begin the path with a slash/solidus \"/\". The '*' character is a wildcard. A good start is /wp-login.php, or /joomla/*. These visitors will be reported to AbuseIPDB in category 'Web App Attack'."),
      '#required' => FALSE,
    ];

    $form['paths_ban_ip'] = [
      '#type' => 'checkbox',
      '#title' => 'Ban IP',
      '#default_value' => $config->get('abuseipdb.paths_ban_ip'),
      '#description' => $this->t('Add the IP to Drupal ban list'),
      '#required' => FALSE,
    ];

    $form['test'] = [
      '#weight' => 1001,
      '#type' => 'textfield',
      '#title' => $this->t('Test a path'),
      '#description' => $this->t('Type a path to test the configuration above. You must Save Configuration to apply changes.'),
      '#required' => FALSE,
      '#field_prefix' => \Drupal::request()->getHost() . '/',
      '#suffix' => '<div id="test-output"></div>',
      '#ajax' => [
        'callback' => '::testPathCallback',
        'disable-refocus' => FALSE,
        'event' => 'keyup',
        'wrapper' => 'test-output',
        'progress' => [
          'type' => 'throbber',
          'checking' => $this->t('looking for match...'),
        ],
      ],
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {

  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $config = $this->configFactory->getEditable('abuseipdb.settings')
      ->set('abuseipdb.paths', $form_state->getValue('paths'))
      ->set('abuseipdb.paths_ban_ip', $form_state->getValue('paths_ban_ip'))
      ->save();
    return parent::submitForm($form, $form_state);
  }

  /**
   * Create test field for blacklist.
   *
   * @param array $form
   * @param FormStateInterface $form_state
   * @return Array
   *   Render array with markup.
   */
  public function testPathCallback(array &$form, FormStateInterface $form_state) {
    $current_path = '/' . $form_state->getValue('test');
    $blacklist = $form_state->getValue('paths');

    $match = \Drupal::service('path.matcher')->matchPath($current_path, $blacklist);

    return [
      '#markup' => '<div id="test-output">' . ($match !== TRUE ? '&#10007; ' : '&#10003; ') . 'Path is ' . ($match !== TRUE ? '<b>not</b> ' : '') . 'matched</div>',
    ];
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'abuseipdb.settings',
    ];
  }

}
